@@ -24,7 +24,6 @@ import time
 # g_start = time.time()
 # def p():
 #     print(time.time() - g_start, __file__, inspect.currentframe().f_back.f_lineno)
-import dbus
 import logging
 import os
 import signal
@@ -32,17 +31,21 @@ import subprocess
 import sys
 import uuid
 
+from locale import gettext as _
 from optparse import OptionParser
 
-from guake import guake_version
-from guake.dbusiface import DBUS_NAME
-from guake.dbusiface import DBUS_PATH
-from guake.dbusiface import DbusManager
-from guake.globals import _
-from guake.guake_logging import setupLogging
-
 log = logging.getLogger(__name__)
 
+from guake.globals import NAME
+from guake.globals import bindtextdomain
+
+# When we are in the document generation on readthedocs, we do not have paths.py generated
+try:
+    from guake.paths import LOCALE_DIR
+    bindtextdomain(NAME, LOCALE_DIR)
+except:  # pylint: disable=bare-except
+    pass
+
 
 def main():
     """Parses the command line parameters and decide if dbus methods
@@ -53,16 +56,29 @@ def main():
     # Force to xterm-256 colors for compatibility with some old command line programs
     os.environ["TERM"] = "xterm-256color"
 
+    # Force use X11 backend underwayland
+    os.environ["GDK_BACKEND"] = "x11"
+
     # do not use version keywords here, pbr might be slow to find the version of Guake module
     parser = OptionParser()
     parser.add_option(
-        '-v',
+        '-V',
         '--version',
         dest='version',
         action='store_true',
         default=False,
         help=_('Show Guake version number and exit')
     )
+
+    parser.add_option(
+        '-v',
+        '--verbose',
+        dest='verbose',
+        action='store_true',
+        default=False,
+        help=_('Enable verbose logging')
+    )
+
     parser.add_option(
         '-f',
         '--fullscreen',
@@ -166,7 +182,7 @@ def main():
         dest='tab_index',
         action='store',
         default='0',
-        help=_('Specify the tab to rename. Default is 0.')
+        help=_('Specify the tab to rename. Default is 0. Can be used to select tab by UUID')
     )
 
     parser.add_option(
@@ -193,8 +209,10 @@ def main():
         metavar='TITLE',
         action='store',
         default='',
-        help=_('Rename the specified tab. Reset to default if TITLE is '
-               'a single dash "-".')
+        help=_(
+            'Rename the specified tab by --tab-index. Reset to default if TITLE is '
+            'a single dash "-".'
+        )
     )
 
     parser.add_option(
@@ -228,9 +246,23 @@ def main():
 
     options = parser.parse_args()[0]
     if options.version:
-        print('Guake Terminal %s' % guake_version())
+        from guake import gtk_version
+        from guake import guake_version
+        from guake import vte_version
+        from guake import vte_runtime_version
+        print('Guake Terminal: {}'.format(guake_version()))
+        print('VTE: {}'.format(vte_version()))
+        print('VTE runtime: {}'.format(vte_runtime_version()))
+        print('Gtk: {}'.format(gtk_version()))
         sys.exit(0)
 
+    import dbus
+
+    from guake.dbusiface import DBUS_NAME
+    from guake.dbusiface import DBUS_PATH
+    from guake.dbusiface import DbusManager
+    from guake.guake_logging import setupLogging
+
     instance = None
 
     # Trying to get an already running instance of guake. If it is not
@@ -242,7 +274,7 @@ def main():
         already_running = True
     except dbus.DBusException:
         # can now configure the logging
-        setupLogging(True)
+        setupLogging(options.verbose)
 
         # COLORTERM is an environment variable set by some terminal emulators such as
         # gnome-terminal.
@@ -250,7 +282,7 @@ def main():
         if "COLORTERM" in os.environ:
             del os.environ['COLORTERM']
 
-        log.info("DBus not running, starting it")
+        log.info("Guake not running, starting it")
         # late loading of the Guake object, to speed up dbus comm
         from guake.guake_app import Guake
         instance = Guake()
